---
title: <span class="badge object-type-scalar"></span> LitrePerMinute
---
# <span class="badge object-type-scalar"></span> LitrePerMinute

Flow: Litre/min (L/min)

## Definition

```python
# Flow: Litre/min (L/min)
LitrePerMinute: typing.Literal["flowlpm"] = "flowlpm"
```
